summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/avdevice/videodevicepool.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/avdevice/videodevicepool.cpp')
-rw-r--r--kopete/libkopete/avdevice/videodevicepool.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/libkopete/avdevice/videodevicepool.cpp b/kopete/libkopete/avdevice/videodevicepool.cpp
index 39f6a7c7..1107a54d 100644
--- a/kopete/libkopete/avdevice/videodevicepool.cpp
+++ b/kopete/libkopete/avdevice/videodevicepool.cpp
@@ -414,7 +414,7 @@ int VideoDevicePool::getFrame()
}
/*!
- \fn VideoDevicePool::getQImage(TQImage *qimage)
+ \fn VideoDevicePool::getTQImage(TQImage *qimage)
*/
int VideoDevicePool::getImage(TQImage *qimage)
{
@@ -623,7 +623,7 @@ int VideoDevicePool::scanDevices()
videodevice_dir.setSorting( TQDir::Name );
kdDebug(14010) << k_funcinfo << "Looking for devices in " << videodevice_dir_path << endl;
- const QFileInfoList *list = videodevice_dir.entryInfoList();
+ const TQFileInfoList *list = videodevice_dir.entryInfoList();
if (!list)
{
@@ -639,7 +639,7 @@ int VideoDevicePool::scanDevices()
videodevice_dir.setSorting( TQDir::Name );
kdDebug(14010) << k_funcinfo << "Looking for devices in " << videodevice_dir_path << endl;
- const QFileInfoList *list = videodevice_dir.entryInfoList();
+ const TQFileInfoList *list = videodevice_dir.entryInfoList();
if (!list)
{
@@ -647,7 +647,7 @@ int VideoDevicePool::scanDevices()
return EXIT_FAILURE;
}
- QFileInfoListIterator fileiterator ( *list );
+ TQFileInfoListIterator fileiterator ( *list );
TQFileInfo *fileinfo;
kdDebug(14010) << k_funcinfo << "scanning devices in " << videodevice_dir_path << "..." << endl;
@@ -655,7 +655,7 @@ int VideoDevicePool::scanDevices()
{
videodevice.setFileName(fileinfo->absFilePath());
kdDebug(14010) << k_funcinfo << "Found device " << videodevice.full_filename << endl;
- videodevice.open(); // It should be opened with O_NONBLOCK (it's a FIFO) but I dunno how to do it using QFile
+ videodevice.open(); // It should be opened with O_NONBLOCK (it's a FIFO) but I dunno how to do it using TQFile
if(videodevice.isOpen())
{
kdDebug(14010) << k_funcinfo << "File " << videodevice.full_filename << " was opened successfuly" << endl;
@@ -675,7 +675,7 @@ int VideoDevicePool::scanDevices()
return EXIT_SUCCESS;
}
- QFileInfoListIterator fileiterator ( *list );
+ TQFileInfoListIterator fileiterator ( *list );
TQFileInfo *fileinfo;
kdDebug(14010) << k_funcinfo << "scanning devices in " << videodevice_dir_path << "..." << endl;
@@ -683,7 +683,7 @@ int VideoDevicePool::scanDevices()
{
videodevice.setFileName(fileinfo->absFilePath());
kdDebug(14010) << k_funcinfo << "Found device " << videodevice.full_filename << endl;
- videodevice.open(); // It should be opened with O_NONBLOCK (it's a FIFO) but I dunno how to do it using QFile
+ videodevice.open(); // It should be opened with O_NONBLOCK (it's a FIFO) but I dunno how to do it using TQFile
if(videodevice.isOpen())
{
kdDebug(14010) << k_funcinfo << "File " << videodevice.full_filename << " was opened successfuly" << endl;
@@ -760,7 +760,7 @@ void VideoDevicePool::loadConfig()
{
KConfig *config = KGlobal::config();
config->setGroup("Video Device Settings");
- const TQString currentdevice = config->readEntry("Current Device", TQString::null);
+ const TQString currentdevice = config->readEntry("Current Device", TQString());
kdDebug(14010) << k_funcinfo << "Current device: " << currentdevice << endl;
// m_current_device = 0; // Must check this thing because of the fact that multiple loadConfig in other methodas can do bad things. Watch out!
@@ -833,7 +833,7 @@ void VideoDevicePool::saveConfig()
}
*/
// Stores what is the current video device in use
- const TQString currentdevice = TQString::fromLocal8Bit ( "Model %1 Device %2" ) .arg(m_videodevice[m_current_device].m_model) .arg(m_videodevice[m_current_device].m_modelindex);
+ const TQString currentdevice = TQString(TQString::fromLocal8Bit ( "Model %1 Device %2" )) .tqarg(m_videodevice[m_current_device].m_model) .tqarg(m_videodevice[m_current_device].m_modelindex);
config->writeEntry( "Current Device", currentdevice);
VideoDeviceVector::iterator vditerator;